@@ -92,53 +92,50 @@ const gchar* translate_func (const gchar * s, gpointer p)
 }
 
 
-
 void AboutDialog( GtkWidget *w, gpointer clocklist )
 {
-  GString *title, *about;
-  gchar *button[]={"OK"};
-  GtkWidget *dialog, *label;
+    GtkWidget *dialog;
 
-  /* at some point in the future strings like these will have to 
-     be reorganised to allow for internationalisation */
-  title = g_string_new(_("About gworldclock"));
-  about = g_string_new(  "\n                                  gworldclock\n");
-#ifdef PACKAGE_VERSION
-  g_string_append(about, "                                     v ");
-  g_string_append(about, PACKAGE_VERSION);
-  g_string_append(about, "\n");
-#endif
-  g_string_append(about, "\n (C) Drew Parsons <dparsons@emerall.com>  ");
+    GString *copyright, *comments, *licence;
+
+    /* set up strings */
+    copyright = g_string_new( "Drew Parsons <dparsons@emerall.com>  " );
 #ifdef RELEASE_DATE
-  g_string_append(about, RELEASE_DATE);
+    g_string_append(copyright, RELEASE_DATE);
 #endif
-  g_string_append(about, "\n Released under the General Public License (GPL) v2.0\n");
 
-  g_string_append(about, "\n gworldclock allows you to keep track of the current time\n");
-  g_string_append(about, " in time zones all round the world.  You may also \"rendezvous\"\n");
-  g_string_append(about, " your time zones to a specified time and date.\n");
+    licence = g_string_new( _("Released under the General Public License (GPL) v2.0") );
 
-  /* I don't want to use a MessageDialog because I don't like the little
-     lamp picture it would add for type INFO. */
-  dialog = gtk_dialog_new_with_buttons (title->str,
-					NULL,
-					0,
-					GTK_STOCK_OK,
-					GTK_RESPONSE_NONE,
-					NULL);
-  label = gtk_label_new( about->str );
-  g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
-			    G_CALLBACK (gtk_widget_destroy),
-			    GTK_OBJECT (dialog));
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox),
-		     label);
-  gtk_widget_show_all (dialog);
+    comments = g_string_new(  _( "gworldclock allows you to keep track of the current time"
+				 " in time zones all round the world.  You may also \"rendezvous\""
+				 " your time zones to a specified time and date.") );
+    
 
+    /* build the about dialog */
+    
+    dialog = gtk_about_dialog_new();
+    
+#ifdef PACKAGE_VERSION
+    gtk_about_dialog_set_version( GTK_ABOUT_DIALOG(dialog), PACKAGE_VERSION );
+#endif
+    gtk_about_dialog_set_copyright( GTK_ABOUT_DIALOG(dialog), copyright->str );
+    gtk_about_dialog_set_comments( GTK_ABOUT_DIALOG(dialog), comments->str );
+    gtk_about_dialog_set_license( GTK_ABOUT_DIALOG(dialog) , licence->str );
+    gtk_about_dialog_set_translator_credits( GTK_ABOUT_DIALOG(dialog), _("translator-credits") );
+
+    gtk_show_about_dialog( NULL,
+       "copyright", gtk_about_dialog_get_copyright( GTK_ABOUT_DIALOG(dialog) ),
+       "license", gtk_about_dialog_get_license( GTK_ABOUT_DIALOG(dialog) ),
+       "comments", gtk_about_dialog_get_comments( GTK_ABOUT_DIALOG(dialog) ),
+		 NULL );
+
+    g_string_free(copyright,TRUE);
+    g_string_free(comments,TRUE);
+    g_string_free(licence,TRUE);
 
-  g_string_free(about,TRUE);
-  g_string_free(title,TRUE);
 }
 
+
 /* ensure we go through the same save routine when quitting from the menu (C-Q)
    or by pressing the window's 'close' button */
 void send_clock_quit( GtkWidget *w, gpointer clocklist )
@@ -147,7 +144,7 @@ void send_clock_quit( GtkWidget *w, gpointer clocklist )
   gint return_val;
   extern gint OKtoQuit;
 
-  gtk_signal_emit_by_name((GtkObject *) gtk_widget_get_toplevel(
+  g_signal_emit_by_name((GObject *) gtk_widget_get_toplevel(
 			     (GtkWidget *)g_object_get_data(clocklist, MAIN_WINDOW)), 
 			  "delete_event", &event, &return_val);
 
@@ -310,8 +307,8 @@ int main( int argc, char *argv[] )
   textdomain(PACKAGE_NAME);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_signal_connect (GTK_OBJECT (window), "destroy", 
-		      GTK_SIGNAL_FUNC (gtk_main_quit), 
+  g_signal_connect (G_OBJECT (window), "destroy", 
+		      G_CALLBACK (gtk_main_quit), 
 		      "WM destroy");
   gtk_window_set_title (GTK_WINDOW(window), "gworldclock");
 
@@ -347,8 +344,9 @@ int main( int argc, char *argv[] )
 						     "text", TZ_DESCRIPTION,
 						     NULL);
   gtk_tree_view_column_set_sizing( column, GTK_TREE_VIEW_COLUMN_AUTOSIZE );
-  g_signal_connect(GTK_OBJECT(column), "notify::width", 
-		   GTK_SIGNAL_FUNC(updateColumnWidth), clocklist);
+
+  g_signal_connect(G_OBJECT(column), "notify::width", 
+		   G_CALLBACK(updateColumnWidth), clocklist);
   gtk_tree_view_append_column (GTK_TREE_VIEW (clocklist), column);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -356,6 +354,7 @@ int main( int argc, char *argv[] )
 						     renderer,
 						     "text", TZ_TIMEDATE,
 						     NULL);
+  gtk_tree_view_column_set_sizing( column, GTK_TREE_VIEW_COLUMN_AUTOSIZE );
   gtk_tree_view_append_column (GTK_TREE_VIEW (clocklist), column);
 
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (clocklist));
@@ -363,7 +362,7 @@ int main( int argc, char *argv[] )
   
   g_signal_connect(G_OBJECT(clocklist),
 		   "button_press_event",
-		   GTK_SIGNAL_FUNC(ButtonPressedInList),
+		   G_CALLBACK(ButtonPressedInList),
 		   (gpointer)select);
 
   gtk_container_add(GTK_CONTAINER(scrolled_window), clocklist);
@@ -371,8 +370,8 @@ int main( int argc, char *argv[] )
   gtk_widget_show (clocklist);
 
   g_object_set_data(G_OBJECT(clocklist), MAIN_WINDOW, window);
-  gtk_signal_connect (GTK_OBJECT (window), "delete_event", 
-		      GTK_SIGNAL_FUNC (worldclock_quit), (gpointer)clocklist);
+  g_signal_connect (G_OBJECT (window), "delete_event", 
+		      G_CALLBACK (worldclock_quit), (gpointer)clocklist);
 
   /* set up menu */
   action_group = gtk_action_group_new ("UIActions");
