@@ -60,7 +60,7 @@ static GtkActionEntry entries[] = {
   { "ChangeDescription", NULL, N_("_Change Description"),  NULL,  NULL, G_CALLBACK(ChangeZoneDescription) },
   { "Rendezvous", NULL, N_("_Rendezvous"),  NULL,  NULL, G_CALLBACK(Rendezvous) },
   { "Help", NULL, N_("_Help") },
-  { "About", NULL, N_("About"),   NULL,         NULL, G_CALLBACK(AboutDialog) }
+  { "About", NULL, N_("_About"),   NULL,         NULL, G_CALLBACK(AboutDialog) }
 };
 
 static GtkToggleActionEntry toggle_entries[] = {
