@@ -26,6 +26,8 @@ how to use XML from within C.
 
 
 
+#include <stdlib.h>
+#include <time.h>
 
 #include <unistd.h> /* getopt */
 #include <gtk/gtk.h>
@@ -186,6 +188,7 @@ void GetOptions( int argc, char **argv )
 	default:
 	break;
      }
+
 }
 
 /* save options to options file (default ~/.gworldclock) 
@@ -264,21 +267,45 @@ void StoreOldPreferences()
    }
 }
 
-void RestoreOldPreferences()
+
+void updateDisplayFormat( GString *newDisplayFormat, gpointer clocklist )
 {
    extern GString *displayFormat;
+   
+   displayFormat = g_string_assign( displayFormat, 
+				    newDisplayFormat->str);
+
+   /* restart timer, in case displayFormat was changed to require or
+      not require seconds */
+   reset_timer(clocklist);
+
+   // update display now, in case timer is set to 60 sec, or else
+   // new display will not be seen for another minute
+   SetTime(clocklist); 
+
+   /* update column size to adapt to new date format */
+   resizeWindow( gtk_widget_get_toplevel( GTK_WIDGET(clocklist) ), clocklist);
+   
+
+   changedPreferences = TRUE;
+
+}
+
+void RestoreOldPreferences( gpointer clocklist )
+{
+   extern GString *displayFormat;
+
    if ( ! g_string_equal( displayFormat, oldTimeDisplayFormat ) )
    {
-      displayFormat = g_string_assign( displayFormat, 
-				       oldTimeDisplayFormat->str);
-      changedPreferences = TRUE;
+       updateDisplayFormat( oldTimeDisplayFormat, clocklist );
    }
 }
 
 /* Updates the user's preferences. */ 
-void ProcessPreferences( GObject *owner )
+void ProcessPreferences( GObject *owner, gpointer clocklist )
 {
    extern GString *displayFormat;
+
    GString *newDisplayFormat;
    GSList *radioGroup;
    GtkEntry *entry;
@@ -309,9 +336,7 @@ void ProcessPreferences( GObject *owner )
 
    if ( ! g_string_equal( displayFormat, newDisplayFormat ) )
    {
-      displayFormat = g_string_assign( displayFormat, 
-				       newDisplayFormat->str);
-      changedPreferences = TRUE;
+       updateDisplayFormat( newDisplayFormat, clocklist );
    }
    g_string_free( newDisplayFormat, TRUE );
 }
@@ -335,13 +360,13 @@ void ProcessPreferenceResponse( GtkDialog *dialog,
    {
       case GTK_RESPONSE_OK:
 	 /* process preferences and close */
-         ProcessPreferences(G_OBJECT(dialog));
+         ProcessPreferences(G_OBJECT(dialog), clocklist);
 	 SavePreferences();
 	 gtk_widget_destroy(GTK_WIDGET(dialog));
          break;
       case GTK_RESPONSE_APPLY:
 	 /* process preferences, keep dialog box open */
-         ProcessPreferences(G_OBJECT(dialog));
+         ProcessPreferences(G_OBJECT(dialog), clocklist);
          break;
       case GTK_RESPONSE_CLOSE:
       case GTK_RESPONSE_DELETE_EVENT:
@@ -350,7 +375,7 @@ void ProcessPreferenceResponse( GtkDialog *dialog,
          break;
       case GTK_RESPONSE_CANCEL:
 	 /* restore original preferences and close */
-	 RestoreOldPreferences();
+	 RestoreOldPreferences(clocklist);
 	 SavePreferences();
 	 gtk_widget_destroy (GTK_WIDGET(dialog));
          break;
@@ -490,7 +515,7 @@ void ChangePreferences(GtkWidget *w, gpointer clocklist)
 					 GTK_STOCK_REVERT_TO_SAVED,
 					 GTK_RESPONSE_CANCEL,
                                          NULL);
-   g_signal_connect (GTK_OBJECT (dialog),
+   g_signal_connect (G_OBJECT (dialog),
 		     "response",
 		     G_CALLBACK (ProcessPreferenceResponse),
 		     (gpointer)clocklist);
