@@ -9,4 +9,4 @@ gint SaveOptions();
 
 /* dialog box allows user to set preferences
    e.g. preferred display format for time and date */
-void ChangePreferences(gpointer clocklist);
+void ChangePreferences(GtkWidget *w, gpointer clocklist);
