@@ -6,6 +6,7 @@
    "rendezvous".
 */
 
+#include <stdlib.h>
 #include <string.h>
 #include <libintl.h>
 #define _(A) gettext(A)
@@ -101,24 +102,24 @@ void setDefaultSyncValues(gchar *description, gchar *timezone)
 
   timeSet = &timeSetStruct;
 
-  label = gtk_object_get_data( (GtkObject *) syncBox, "label" );
+  label = g_object_get_data( G_OBJECT(syncBox), "label" );
   gtk_label_set_text( (GtkLabel *) label, description);
 
   /* initialise time from sync time if syncing has started */
   if ( timer == -1) {
-    oldtimezone = gtk_object_get_data( (GtkObject *) syncBox, "timezone"  );
+    oldtimezone = g_object_get_data( G_OBJECT(syncBox), "timezone"  );
     t = extractSyncTime();
   }
 
-  gtk_object_set_data( (GtkObject *) syncBox, "timezone", (gpointer) timezone );
+  g_object_set_data( G_OBJECT(syncBox), "timezone", (gpointer) timezone );
 
-  day = gtk_object_get_data( (GtkObject *) syncBox, "day" );
-  month = gtk_object_get_data( (GtkObject *) syncBox, "month" );
-  year = gtk_object_get_data( (GtkObject *) syncBox, "year" );
-  hour = gtk_object_get_data( (GtkObject *) syncBox, "hour" );
-  minute = gtk_object_get_data( (GtkObject *) syncBox, "minute" );
+  day = g_object_get_data( G_OBJECT(syncBox), "day" );
+  month = g_object_get_data( G_OBJECT(syncBox), "month" );
+  year = g_object_get_data( G_OBJECT(syncBox), "year" );
+  hour = g_object_get_data( G_OBJECT(syncBox), "hour" );
+  minute = g_object_get_data( G_OBJECT(syncBox), "minute" );
 
-  TZdefault = (gchar *)getenv("TZ");
+  TZdefault = getenv("TZ");
 
   /* assign time zone in which time is to be given, if not "Local". */
   if(strcasecmp(timezone,"Local"))    
@@ -144,30 +145,27 @@ void setDefaultSyncValues(gchar *description, gchar *timezone)
 
   /* place the various bits of data into their fields */
 
-  dayHandler =(gint *) gtk_object_get_data( (GtkObject *) day, "dayHandler" );
-  gtk_signal_handler_block( (GtkObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) day ), 
+  dayHandler =(gint *) g_object_get_data( G_OBJECT(day), "dayHandler" );
+  g_signal_handler_block( (GObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) day ), 
 			    *dayHandler );
   asprintf( &s, "%i", timeSet->tm_mday );
   gtk_spin_button_set_value( (GtkSpinButton *)day, atoi(s) );
   free( s );
-  gtk_signal_handler_unblock(  
-     (GtkObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) day ), 
+  g_signal_handler_unblock(  
+     (GObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) day ), 
      *dayHandler );
 
-
-  s = getNameOfMonth( (timeSet->tm_mon) + 1 );
-  gtk_entry_set_text( GTK_ENTRY(GTK_COMBO(month)->entry), strdup(s) );
-  free( s );
+  gtk_combo_box_set_active( GTK_COMBO_BOX(month), timeSet->tm_mon);
 
   /* keep the year spin button from handling value_changed,
      or the clock will try to update before it's ready! */
-  yearHandler = (gint *)gtk_object_get_data( (GtkObject *) year, "yearHandler" );
-  gtk_signal_handler_block( (GtkObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) year ), 
+  yearHandler = (gint *)g_object_get_data( G_OBJECT(year), "yearHandler" );
+  g_signal_handler_block( (GObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) year ), 
 			    *yearHandler );
   asprintf( &s, "%i", (1900 + timeSet->tm_year) );
   gtk_spin_button_set_value( (GtkSpinButton *)year, atoi(s) );
   free( s );
-  gtk_signal_handler_unblock(  (GtkObject *)(GtkObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) year ), 
+  g_signal_handler_unblock(  (GObject *)(GtkObject *)gtk_spin_button_get_adjustment((GtkSpinButton *) year ), 
 			       *yearHandler );
 
   asprintf( &s, "%.2i", timeSet->tm_hour);
@@ -224,9 +222,9 @@ void Rendezvous(GtkWidget *w, gpointer clocklist)
       
        /* set sync values to current time */
        setDefaultSyncValues(description, timezone);
-      
+
       if ( timer != -1 ) {
-	 
+
 	 /* freeze timer */
 	 stop_timer();
 
@@ -256,7 +254,8 @@ void Rendezvous(GtkWidget *w, gpointer clocklist)
 	  }
       }
 
-      
+      synchroniseTimes( NULL, (gpointer) clocklist);
+     
       /* and change display to correspond to given time */
       gtk_widget_show( (GtkWidget *) syncBox );
 
@@ -306,23 +305,22 @@ time_t extractSyncTime()
 
   timeSet = &timeSetStruct;
 
-  day = gtk_object_get_data( (GtkObject *) syncBox, "day" );
-  month = gtk_object_get_data( (GtkObject *) syncBox, "month" );
-  year = gtk_object_get_data( (GtkObject *) syncBox, "year" );
-  hour = gtk_object_get_data( (GtkObject *) syncBox, "hour" );
-  minute = gtk_object_get_data( (GtkObject *) syncBox, "minute" );
+  day = g_object_get_data( G_OBJECT(syncBox), "day" );
+  month = g_object_get_data( G_OBJECT(syncBox), "month" );
+  year = g_object_get_data( G_OBJECT(syncBox), "year" );
+  hour = g_object_get_data( G_OBJECT(syncBox), "hour" );
+  minute = g_object_get_data( G_OBJECT(syncBox), "minute" );
 
   newDay = gtk_spin_button_get_value_as_int( (GtkSpinButton *) day );
-  /* don't forget to knock 1 off, since struct tm counts months 0 to 11 */
-  newMonth = getMonthIndex( (gchar *)gtk_entry_get_text( GTK_ENTRY(GTK_COMBO(month)->entry) ) ) - 1;
+  newMonth = gtk_combo_box_get_active(GTK_COMBO_BOX(month));
   newYear = gtk_spin_button_get_value_as_int( (GtkSpinButton *) year ) - 1900;
   newHour = atoi( gtk_entry_get_text( GTK_ENTRY(hour) ) );
   newMinute = atoi( gtk_entry_get_text( GTK_ENTRY(minute) ) );
 
-  TZdefault = (gchar *)getenv("TZ");
+  TZdefault = getenv("TZ");
     
   /* assign time zone in which time is to be given, if not "Local". */
-  timezone = gtk_object_get_data( (GtkObject *) syncBox, "timezone" );
+  timezone = g_object_get_data( G_OBJECT(syncBox), "timezone" );
   if(strcasecmp(timezone,"Local"))    
     setenv("TZ",timezone,1);
 
@@ -410,19 +408,35 @@ void unsynchronise( GtkWidget *w, gpointer clocklist)
   rendezvousIsActive = FALSE;
 }
 
-GList *initialiseMonthList(GList *listMonths)
+/* after done synchronising zones and the Done button has been
+  clicked, return back to current time. Goes through the Rendezvous
+  toggle action, to make sure it is switched off as well.  */
+void unsynchroniseFromDone( GtkWidget *w, gpointer clocklist)
+{
+  GtkToggleAction *toggleAction;
+
+  /* Check the Rendezvous main menu item is toggled off, if we got
+     here via the "Done" button */
+  toggleAction = GTK_TOGGLE_ACTION( gtk_action_group_get_action(
+		   GTK_ACTION_GROUP( g_object_get_data(G_OBJECT(clocklist), 
+		   ACTIONS) ),
+	  "ToggleRendezvous" ) );
+
+  // go to unsynchronise by toggle the Rendezvous button off
+  gtk_toggle_action_set_active( toggleAction, FALSE );
+
+}
+
+void initialiseMonthList(GObject *months)
 {
    gint i;
-   gchar *monthName;
    
     /* months in year by name (as set by locale) */
-   listMonths = NULL;
    for ( i=1; i<=12; i++ )  
    {
-      monthName = getNameOfMonth( i );
-      listMonths = g_list_append(listMonths, strdup(monthName));
+      gtk_combo_box_append_text(GTK_COMBO_BOX(months),
+				getNameOfMonth( i ) );
    }
-   return listMonths;
 }
 
 /* construct the box in which the controls for synchronising dates will be 
@@ -474,14 +488,6 @@ GtkBox *constructSyncBox(gpointer clocklist)
    gtk_box_pack_start(GTK_BOX(set), date, FALSE, FALSE, 0);  
    gtk_widget_show( date );
    
-   /*  day = gtk_combo_new();
-       gtk_combo_set_popdown_strings( GTK_COMBO(day), list31days) ;
-       gtk_widget_set_usize( day, digitWidth*3, -1);
-       gtk_box_pack_start(GTK_BOX(set), day, FALSE, FALSE, 0);  
-       gtk_signal_connect (GTK_OBJECT( GTK_COMBO(day)->entry ), "activate",
-       GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
-       gtk_widget_show( day );
-   */
    /* just use days 1 to 31 for now */
    adj = gtk_adjustment_new (0, 1, 31, 1, 5, 0);
    day = gtk_spin_button_new ((GtkAdjustment *)adj, 0.1, 0);
@@ -494,21 +500,17 @@ GtkBox *constructSyncBox(gpointer clocklist)
       while the syncBox is being populated with data */
    dayHandler = (gint *) g_malloc( sizeof(gint) );
    *dayHandler = 
-      gtk_signal_connect (GTK_OBJECT(adj), "value_changed",
-			 GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
-   gtk_object_set_data( (GtkObject *)day, "dayHandler", (gpointer) dayHandler);
+       g_signal_connect (G_OBJECT(adj), "value_changed",
+			 G_CALLBACK (synchroniseTimes),  (gpointer)clocklist);
+   g_object_set_data( G_OBJECT(day), "dayHandler", (gpointer) dayHandler);
    gtk_widget_show( day );
   
   
-   month = gtk_combo_new();
-   monthList = initialiseMonthList(monthList);
-   gtk_combo_set_popdown_strings( GTK_COMBO(month), monthList) ;
-   gtk_combo_set_use_arrows_always( (GtkCombo *)month, TRUE );
-   /* add 5 characters to cover size of arrow */
-   gtk_widget_set_usize( month, (getLongestEntry(monthList)+5)*charWidth, -1);
-   gtk_box_pack_start(GTK_BOX(set), month, FALSE, FALSE, 0);  
-   gtk_signal_connect (GTK_OBJECT (GTK_COMBO(month)->entry), "activate",
-		       GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
+   month = gtk_combo_box_new_text();
+   initialiseMonthList(G_OBJECT(month));
+   gtk_box_pack_start(GTK_BOX(set), month, FALSE, FALSE, 2);
+   g_signal_connect (G_OBJECT (month), "changed",
+		       G_CALLBACK (synchroniseTimes),  (gpointer)clocklist);
    gtk_widget_show( month );
    
    
@@ -526,9 +528,9 @@ GtkBox *constructSyncBox(gpointer clocklist)
       while the syncBox is being populated with data */
    yearHandler = (gint *) g_malloc( sizeof(gint) );
    *yearHandler = 
-      gtk_signal_connect (GTK_OBJECT(adj), "value_changed",
-			  GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
-   gtk_object_set_data( (GtkObject *)year, "yearHandler", (gpointer) yearHandler);
+      g_signal_connect (G_OBJECT(adj), "value_changed",
+			  G_CALLBACK (synchroniseTimes),  (gpointer)clocklist);
+   g_object_set_data( G_OBJECT(year), "yearHandler", (gpointer) yearHandler);
    gtk_widget_show( year );
    
    gtk_box_pack_start(GTK_BOX(line), set, TRUE, FALSE, 0);  
@@ -548,8 +550,8 @@ GtkBox *constructSyncBox(gpointer clocklist)
    hour = gtk_entry_new_with_max_length(2);
    gtk_entry_set_width_chars( GTK_ENTRY(hour), 2 );
    gtk_box_pack_start(GTK_BOX(set), hour, FALSE, FALSE, 0);  
-   gtk_signal_connect (GTK_OBJECT (hour), "activate",
-		       GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
+   g_signal_connect (G_OBJECT (hour), "activate",
+		       G_CALLBACK (synchroniseTimes),  (gpointer)clocklist);
    gtk_widget_show( hour );
    
    colon = gtk_label_new(":");
@@ -560,8 +562,8 @@ GtkBox *constructSyncBox(gpointer clocklist)
    minute = gtk_entry_new_with_max_length(2);
    gtk_entry_set_width_chars( GTK_ENTRY(minute), 2 );
    gtk_box_pack_start(GTK_BOX(set), minute, FALSE, FALSE, 0);  
-   gtk_signal_connect (GTK_OBJECT (minute), "activate",
-		       GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
+   g_signal_connect (G_OBJECT (minute), "activate",
+		       G_CALLBACK (synchroniseTimes),  (gpointer)clocklist);
    gtk_widget_show( minute );
    
    gtk_box_pack_start(GTK_BOX(line), set, TRUE, FALSE, 0);  
@@ -574,8 +576,8 @@ GtkBox *constructSyncBox(gpointer clocklist)
    /* button to set to new time (for those who dislike the return button */
    button = gtk_button_new_with_label(_("Update View"));
    gtk_box_pack_start(GTK_BOX(line), button, TRUE, FALSE, 0);  
-   gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		       GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
+   g_signal_connect (G_OBJECT (button), "clicked",
+		       G_CALLBACK (synchroniseTimes),  (gpointer)clocklist);
    gtk_widget_show (button);
    
    /* button to close synchronisation, return to current time */
@@ -587,19 +589,19 @@ GtkBox *constructSyncBox(gpointer clocklist)
    g_string_free( doneLabel, TRUE );
 
    gtk_box_pack_start(GTK_BOX(line), button, TRUE, FALSE, 0);  
-   gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		       GTK_SIGNAL_FUNC (unsynchronise),  (gpointer)clocklist);
+   g_signal_connect (G_OBJECT (button), "clicked",
+		       G_CALLBACK(unsynchroniseFromDone),  (gpointer)clocklist);
    gtk_widget_show (button);
    
    gtk_box_pack_start(GTK_BOX(box), line, FALSE, FALSE, 0);  
    gtk_widget_show( line );
    
-   gtk_object_set_data( (GtkObject *)box, "label", (gpointer) label);
-   gtk_object_set_data( (GtkObject *)box, "day", (gpointer) day);
-   gtk_object_set_data( (GtkObject *)box, "month", (gpointer) month);
-   gtk_object_set_data( (GtkObject *)box, "year", (gpointer) year);
-   gtk_object_set_data( (GtkObject *)box, "hour", (gpointer) hour);
-   gtk_object_set_data( (GtkObject *)box, "minute", (gpointer) minute);
+   g_object_set_data( G_OBJECT(box), "label", (gpointer) label);
+   g_object_set_data( G_OBJECT(box), "day", (gpointer) day);
+   g_object_set_data( G_OBJECT(box), "month", (gpointer) month);
+   g_object_set_data( G_OBJECT(box), "year", (gpointer) year);
+   g_object_set_data( G_OBJECT(box), "hour", (gpointer) hour);
+   g_object_set_data( G_OBJECT(box), "minute", (gpointer) minute);
    
    return (GtkBox *)box;
 }
