@@ -56,7 +56,7 @@ void synchroniseTimes( GtkWidget *field, gpointer clocklist);
 /* after done synchronising zones, return back to current time */
 void unsynchronise( GtkWidget *button, gpointer clocklist);
 
-GList *initialiseMonthList(GList *listMonths);
+void initialiseMonthList(GObject *months);
 
 /* construct the box in which the controls for synchronising dates will be 
    found */
