@@ -1,7 +1,9 @@
 #include <stdio.h>
+#include <stdlib.h>
 #include <errno.h>
 #include <gtk/gtk.h>
 #include <time.h>
+#include <string.h>
 
 #include "main.h"
 #include "timer.h"
@@ -156,14 +158,40 @@ gboolean SetToGivenTime  (GtkTreeModel *clocklistModel,
 
 gint start_timer( gpointer clocklist )
 {
-  return g_timeout_add( 1000, SetTime, clocklist);
+    /* by default update every minute = 60,000 ms */
+    int beatInterval = 60000;
+
+    /* 
+       Change to seconds beat when needed.
+       All the date formats which show seconds are listed here. 
+    */
+    if ( strstr( displayFormat->str, "%c" ) ||
+	 strstr( displayFormat->str, "%N" ) ||
+	 strstr( displayFormat->str, "%r" ) ||
+	 strstr( displayFormat->str, "%s" ) ||
+	 strstr( displayFormat->str, "%S" ) ||
+	 strstr( displayFormat->str, "%T" ) ||
+	 strstr( displayFormat->str, "%X" )   )
+    {
+	beatInterval = 1000;
+    }
+
+    return g_timeout_add( beatInterval, SetTime, clocklist);
 }
 
 void stop_timer()
 {
    extern gint timer;
    g_source_remove( timer );
+
    /* set timer to -1 to show that there is no timer, and therefore
       synchronisation is taking place */
    timer = -1;
 }
+
+void reset_timer( gpointer clocklist )
+{
+    extern gint timer;
+    stop_timer();
+    timer = start_timer( clocklist );
+}
