@@ -245,7 +245,7 @@ GSList* FetchRegions(gchar *country)
   gchar line[500];
   gchar *code, *TZvalue, *region, *ptr;
   GSList *Regions;
-  
+
   if (strlen(country)==0 )
     return NULL;
 
@@ -262,16 +262,13 @@ GSList* FetchRegions(gchar *country)
   Regions=NULL;
   while(fgets(line,500,fp)) {
     if (line[0] != '#') {
-      
       /* check for entries corresponding to country code value 
 	 (first item on the line in ZONE_TABLE)
 	 Get name of region from third item on the line. */
       /* alternatively we may want to get the description from the optional
 	 fourth item, where available.  Worry about that some other time */
       sscanf(line,"%as %*s %as",&code,&TZvalue);
-
       if(!strcmp(code,country)) {
-
 	/* region name is in format:  continent/region
 	   Extract the region part from the continent */
 	ptr = (gchar *) strchr(TZvalue,'/');
@@ -298,122 +295,297 @@ GSList* FetchRegions(gchar *country)
   return Regions;
 }
 
-void UpdateCountries(GtkWidget *ContinentCList,
-		     gint row,
-		     gint column,
-		     GdkEventButton *event,
-		     gpointer ZoneData)
+void UpdateCountries(GtkTreeSelection *selection, gpointer ZoneNotes)
 {
-  gchar *continent, *ptr;
-  GSList *Countries, *item;
-  gchar *rowdata[1];
-  gint newRow;
-  GtkCList *clist;
+    GtkTreeIter iter ;
+    GtkTreeModel *model;
+    gchar *continent;
 
-  gtk_clist_get_text( (GtkCList *) ContinentCList, row, 0, &ptr);
+    GtkTreeModel *store;
+    GtkTreeModel *filteredStore;
+    GtkTreePath *path;
+    GtkWidget *tree;
+    GtkWidget *scrolled_window;
+    GtkTreeSelection *countrySelection;
+    
+    AddZoneStruct *zoneData;
 
-  /* check value of continent here  */
-  continent = g_strdup(ptr);
-  /* change "Americas" to "America" by wiping out the 's' */
-  if(!strcmp(continent,"Americas"))
-    continent[7]='\0';
+    if (gtk_tree_selection_get_selected (selection, &model, &iter))
+    {
+	gtk_tree_model_get (model, &iter, CONTINENT_NAME, &continent, -1);
 
-  /* similarly remove " Ocean" in "Pacific Ocean", etc
-     by making the ' ' a null character */
-  ptr = (gchar *) strchr(continent,' ');
-  if(ptr)
-    *ptr='\0';
+	filteredStore = gtk_tree_view_get_model( gtk_tree_selection_get_tree_view(selection) );
+	store = gtk_tree_model_filter_get_model( GTK_TREE_MODEL_FILTER(filteredStore) );
+	path = gtk_tree_model_get_path( GTK_TREE_MODEL(filteredStore), &iter );	    
+	path = gtk_tree_model_filter_convert_path_to_child_path( GTK_TREE_MODEL_FILTER(filteredStore), path );
 
-  clist = (GtkCList *) ((AddZoneStruct*)ZoneData)->countryCList;
-  Countries=FetchCountries(continent);
-  gtk_clist_freeze( clist );
-  gtk_clist_clear( clist ); 
-  item = Countries;
-  while(item) {
-    rowdata[0]=g_strdup( ((NameCodeType *)item->data)->name);
-    newRow=gtk_clist_append(clist, rowdata);
-    gtk_clist_set_row_data( clist, newRow, 
-			    g_strdup(((NameCodeType *)item->data)->code));
-    g_free(rowdata[0]);
-    item = item->next;
-  }
-  ClearNameCodeList(&Countries);
-  g_free(continent);
-  gtk_clist_select_row( clist,0,0); 
-  gtk_clist_thaw( clist );
 
+	filteredStore = gtk_tree_model_filter_new( GTK_TREE_MODEL(store), path );
+	if ( path ) gtk_tree_path_free( path );
+	
+	gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(filteredStore),
+					       FilterCountries,
+					       NULL, NULL );
+	
+	GtkWidget *label = gtk_label_new( _("Countries") );
+	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL(filteredStore));
+	gtk_tree_view_set_headers_visible( GTK_TREE_VIEW(tree), FALSE );
+	gtk_widget_show(tree);
+
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
+	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes ("Name",
+							   renderer,
+							   "text", COUNTRY_NAME,
+							   NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
+
+	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+                                  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+	gtk_widget_show (scrolled_window);
+	gtk_container_add(GTK_CONTAINER(scrolled_window), tree);
+
+	gtk_notebook_remove_page( (GtkNotebook*)ZoneNotes, COUNTRY_NAME );
+	gtk_notebook_insert_page ( (GtkNotebook*)ZoneNotes, scrolled_window, 
+				  label, COUNTRY_NAME );
+
+	countrySelection = gtk_tree_view_get_selection( GTK_TREE_VIEW(tree) );
+	gtk_tree_selection_set_mode (countrySelection, GTK_SELECTION_SINGLE);
+	g_signal_connect (G_OBJECT (countrySelection), "changed",
+			  G_CALLBACK (UpdateRegions),
+			  ZoneNotes);
+
+	zoneData = (AddZoneStruct*) g_object_get_data(G_OBJECT(ZoneNotes),ZONE_DATA);
+	zoneData->countryTreeView = GTK_TREE_VIEW(tree);
+
+	/* update region list straight away to match first country on
+	  this continent  */
+	gtk_tree_model_get_iter_first(GTK_TREE_MODEL(filteredStore),
+				      &iter);
+	gtk_tree_selection_select_iter(countrySelection, &iter);
+
+	g_free (continent);
+    }
 }
 
-/*  Why does the scroll box get larger when you keep selecting a country?? */
-void UpdateRegions(GtkWidget *CountryCList,
-		   gint row,
-		   gint column,
-		   GdkEventButton *event,
-		   gpointer ZoneData)
+void UpdateRegions(GtkTreeSelection *selection, gpointer ZoneNotes)
 {
-  gchar *country;
-  GSList *Regions, *item;
-  gchar *rowdata[1];
-  gint newRow;
-  GtkCList *clist;
+    GtkTreeIter iter ;
+    GtkTreeModel *model;
+    gchar *country;
 
-  country = (gchar *) gtk_clist_get_row_data( (GtkCList *) CountryCList, row);
+    GtkTreeModel *store;
+    GtkTreeModel *filteredStore;
+    GtkTreePath *path;
+    GtkWidget *tree;
+    GtkTreeSelection *regionSelection;
+    GtkWidget *scrolled_window;
 
-  clist = (GtkCList *) ((AddZoneStruct*)ZoneData)->regionCList;
-  Regions=FetchRegions(country);
-  gtk_clist_freeze( clist );
-  gtk_clist_clear( clist ); 
-  item = Regions;
-  while(item) {
-    rowdata[0]=g_strdup( ((NameCodeType *)item->data)->name);
-    newRow=gtk_clist_append(clist, rowdata);
-    gtk_clist_set_row_data( clist, 
-			    newRow, g_strdup(((NameCodeType *)item->data)->code));
-    g_free(rowdata[0]);
-    item = item->next;
-  }
-  ClearNameCodeList(&Regions);
-  gtk_clist_thaw( clist );
+    AddZoneStruct *zoneData;
+
+    if (gtk_tree_selection_get_selected (selection, &model, &iter))
+    {
+	gtk_tree_model_get (model, &iter, COUNTRY_NAME, &country, -1);
+
+	filteredStore = gtk_tree_view_get_model( gtk_tree_selection_get_tree_view(selection) );
+	store = gtk_tree_model_filter_get_model( GTK_TREE_MODEL_FILTER(filteredStore) );
+	path = gtk_tree_model_get_path( GTK_TREE_MODEL(filteredStore), &iter );	    
+	path = gtk_tree_model_filter_convert_path_to_child_path( GTK_TREE_MODEL_FILTER(filteredStore), path );
+
+
+	filteredStore = gtk_tree_model_filter_new( GTK_TREE_MODEL(store), path );
+	if ( path ) gtk_tree_path_free( path );
+	
+	gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(filteredStore),
+					       FilterRegions,
+					       NULL, NULL );
+	
+	GtkWidget *label = gtk_label_new( _("Regions") );
+	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL(filteredStore));
+	gtk_tree_view_set_headers_visible( GTK_TREE_VIEW(tree), FALSE );
+	gtk_widget_show(tree);
+
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
+	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes ("Name",
+							   renderer,
+							   "text", REGION_NAME,
+							   NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
+
+	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+                                  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+	gtk_widget_show (scrolled_window);
+	gtk_container_add(GTK_CONTAINER(scrolled_window), tree);
+
+	gtk_notebook_remove_page( (GtkNotebook*)ZoneNotes, REGION_NAME );
+	gtk_notebook_insert_page( (GtkNotebook*)ZoneNotes, scrolled_window, 
+				  label, REGION_NAME );
+
+	regionSelection = gtk_tree_view_get_selection(GTK_TREE_VIEW (tree));
+	gtk_tree_selection_set_mode (regionSelection, GTK_SELECTION_SINGLE);
+	g_signal_connect( G_OBJECT(regionSelection), "changed",
+			  G_CALLBACK(SelectRegion),
+			  g_object_get_data(G_OBJECT(ZoneNotes),ZONE_DATA));
+
+	g_signal_connect(G_OBJECT(tree),
+			 "button_press_event",
+			 G_CALLBACK(ButtonPressedInRegionList),
+			 (gpointer)g_object_get_data(G_OBJECT(ZoneNotes),ZONE_DATA));
+
+	zoneData = (AddZoneStruct*) g_object_get_data(G_OBJECT(ZoneNotes),ZONE_DATA);
+	zoneData->regionTreeView = GTK_TREE_VIEW(tree);
+
+	g_free (country);
+    }
 }
 
-void SelectRegion(GtkWidget *RegionCList,
-		  gint row,
-		  gint column,
-		  GdkEventButton *event,
-		  gpointer ZoneData)
+void SelectRegion(GtkTreeSelection *selection, gpointer ZoneData)
 {
-  gchar *description, *TZ;
+    GtkTreeIter iter ;
+    GtkTreeModel *model;
+    gchar *description, *TZ;
 
-  gtk_clist_get_text( (GtkCList *) RegionCList, row, 0, &description);
-  TZ = (gchar *) gtk_clist_get_row_data( (GtkCList *) RegionCList, row);
-  
-  gtk_entry_set_text( (GtkEntry *)((AddZoneStruct*)ZoneData)->DescriptionEntry, 
-		      description);
-  gtk_entry_set_text( (GtkEntry *)((AddZoneStruct*)ZoneData)->TZEntry, TZ);
+    if (gtk_tree_selection_get_selected (selection, &model, &iter))
+    {
+	gtk_tree_model_get (model, &iter, REGION_NAME, &description, 
+			    CODE, &TZ,
+			    -1);
+    
+	gtk_entry_set_text( (GtkEntry *)((AddZoneStruct*)ZoneData)->DescriptionEntry, 
+			    description);
+	gtk_entry_set_text( (GtkEntry *)((AddZoneStruct*)ZoneData)->TZEntry, TZ);
+
+	g_free( description );
+	g_free( TZ );
+    }
 }
 
 /* when left mouse button is double-clicked,
    send "key-pressed-event" to one of the Entry boxes 
    which will be handled by adding the given zone.
    We're assuming here that "select-row" preceded the double-click event */
-gint ButtonPressedInRegionList(GtkWidget *regionlist, 
-			       GdkEventButton *event, gpointer ZoneData)
+gboolean ButtonPressedInRegionList (GtkWidget *regionTreeView, 
+				     GdkEventButton *event,
+				     gpointer ZoneData)
 {
-  GdkEventKey *KeyEvent;
-  gint return_val;
-  
-  if( (event->type==GDK_2BUTTON_PRESS) && (event->button==1)) {
-    KeyEvent = (GdkEventKey*)g_malloc(sizeof(GdkEventKey));
-    KeyEvent->keyval=GDK_Return;
-    gtk_signal_emit_by_name( GTK_OBJECT( ((AddZoneStruct*)ZoneData)->TZEntry ),
-			     "key-press-event", (GdkEvent*)KeyEvent, &return_val);
-    g_free(KeyEvent);
-    return TRUE;
-  }
-  return FALSE;
+    GdkEventKey *KeyEvent;
+    
+    static GtkWidget *popup;
+    
+    gboolean returnVal = FALSE;
+    
+    if( (event->button==1) && ( event->type==GDK_2BUTTON_PRESS))
+    {
+       KeyEvent = (GdkEventKey*)g_malloc(sizeof(GdkEventKey));
+       KeyEvent->keyval=GDK_Return;
+       gint return_val;
+       g_signal_emit_by_name( G_OBJECT( ((AddZoneStruct*)ZoneData)->TZEntry ),
+				"key-press-event", (GdkEvent*)KeyEvent, &return_val);
+       g_free(KeyEvent);
+       returnVal = TRUE;
+    }
+
+    return returnVal;
 }
 
 
+/* Initialises (preexisting) iter to the node for the given column
+   (whose value is identified by name) and returns TRUE.  Iter is
+   invalid and FALSE returned, if there is no such name in the column.
+*/ 
+gboolean findRow( GtkTreeModel *model, const gint column, const gchar *nameToMatch, GtkTreeIter *iter )
+{
+    if( ! gtk_tree_model_get_iter_first( model, iter ) )
+	return FALSE;
+
+    gchar* name;
+    gtk_tree_model_get( model, iter, column, &name, -1 );
+    if ( name && !strcmp( nameToMatch, name ) )
+    {
+	g_free( name );
+	return TRUE;
+    }
+    g_free(name);
+
+    while( gtk_tree_model_iter_next( model, iter) )
+    {
+	gtk_tree_model_get( model, iter, column, &name, -1 );
+	if ( name && !strcmp( nameToMatch, name ) )
+	{
+	    g_free(name);
+	    return TRUE;
+	}
+    }
+    g_free(name);
+
+    return FALSE;
+}
+
+
+/* Implements GtkTreeModelFilterVisibleFunc, making continent entries
+   only visible.
+*/
+gboolean FilterContinents(GtkTreeModel *model,
+			  GtkTreeIter *iter,
+			  gpointer data)
+{
+    gboolean visible;
+
+    gchar *continentName;
+    gchar *countryName;
+    gchar *regionName;
+
+    gtk_tree_model_get( model, iter, 
+			CONTINENT_NAME, &continentName, 
+			COUNTRY_NAME, &countryName, 
+			REGION_NAME, &regionName, 
+			-1 );
+
+    visible = ( continentName && strlen(continentName)>0 ) && 
+	( (!countryName) || strlen(countryName)==0 ) &&
+	( (!regionName) || strlen(regionName)==0 ) ;
+
+    g_free( continentName );
+    g_free( countryName );
+    g_free( regionName );
+
+    return visible;
+}
+
+gboolean FilterCountries(GtkTreeModel *model,
+			 GtkTreeIter *iter,
+			 gpointer data)
+{
+    gboolean visible;
+    gchar *countryName;
+    gtk_tree_model_get( model, iter, 
+			COUNTRY_NAME, &countryName, 
+			-1 );
+
+    visible = ( countryName && strlen(countryName)>0 );
+
+    g_free( countryName );
+
+    return visible;
+}
+
+gboolean FilterRegions(GtkTreeModel *model,
+		       GtkTreeIter *iter,
+		       gpointer data)
+{
+    gboolean visible;
+    gchar *regionName;
+    gtk_tree_model_get( model, iter, 
+			REGION_NAME, &regionName, 
+			-1 );
+
+    visible = ( regionName && strlen(regionName)>0 );
+    g_free( regionName );
+
+    return visible;
+}
+
 
 /* zones are selected according to the method used in tzselect:
    First the continent is chosen, then, if necessary, the country is chosen,
@@ -425,103 +597,168 @@ gint ButtonPressedInRegionList(GtkWidget *regionlist,
 
 void  PrepareZoneNotes(GtkWidget **ZoneNotes, AddZoneStruct *Zone)
 {
-  GtkWidget *label;
-  GtkWidget *scrolled_window;
-  GtkWidget *continentCList, *countryCList, *regionCList;
-  gchar *ContinentLabel=_("Continents");
-  gchar *CountryLabel=_("Countries");
-  gchar *RegionLabel=_("Regions");
-  gchar *rowdata[1];
-  gint row, i;
+    gint i;
+    GtkTreeIter continentIter, countryIter, regionIter, iter;
+    GtkTreePath *path;
+    GtkTreeSelection *selection;
+    GSList *countryList, *countryItem;
+    GSList *regionList, *regionItem;
+    gchar *name, *code;
+    gchar *continentName, *ptr;
+    gchar *ContinentLabel=_("Continents");
+    gchar *CountryLabel=_("Countries");
+    gchar *RegionLabel=_("Regions");
+    gint columnId;
 
-  *ZoneNotes = gtk_notebook_new ();
-  gtk_widget_show(*ZoneNotes);
+    /* collate date into a three-level tree.
+       The first level represents continents,
+       the second is regions/countries,
+       the third is cities.
+    */
+   GtkTreeStore *store = gtk_tree_store_new (N_COLUMNS, 
+					     G_TYPE_STRING,
+					     G_TYPE_STRING,
+					     G_TYPE_STRING,
+					     G_TYPE_STRING ); 
 
-  label = gtk_label_new (ContinentLabel);
+    for( i=0; i<Ncontinents; i++) 
+    {
+	gtk_tree_store_append (store, &continentIter, NULL);
+	gtk_tree_store_set (store, &continentIter,
+			    CONTINENT_NAME, continents[i],
+			    -1);
+
+	/* add countries within that continent */
+	continentName = g_strdup(continents[i]);
+	/* change "Americas" to "America" by wiping out the 's' */
+	if(!strcmp(continentName,"Americas"))
+	    continentName[7]='\0';
+
+	/* similarly remove " Ocean" in "Pacific Ocean", etc
+	   by making the ' ' a null character */
+	ptr = (gchar *) strchr(continentName,' ');
+	if(ptr)
+	    *ptr='\0';
+
+	countryList=FetchCountries(continentName);
+	g_free(continentName);
+	countryItem = countryList;
+	while( countryItem ) 
+	{
+	    name = ((NameCodeType *)countryItem->data)->name;
+	    code = ((NameCodeType *)countryItem->data)->code;
+	    gtk_tree_store_append (store, &countryIter, &continentIter);
+	    gtk_tree_store_set (store, &countryIter,
+				COUNTRY_NAME, name,
+				CODE, code,
+				-1);
 
 
-  /* Create a scrolled window to pack the CList widget into */
-  /* can't decide if I want it or not, for continents at least */
-  /*  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-      gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-      GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-      gtk_widget_show (scrolled_window);
-  */
+	    /* add regions and cities within that country */
+	    regionList=FetchRegions(code);
+	    regionItem = regionList;
+	    while( regionItem ) 
+	    {
+		gtk_tree_store_append (store, &regionIter, &countryIter);
+		name = ((NameCodeType *)regionItem->data)->name;
+		code = ((NameCodeType *)regionItem->data)->code;
 
-  /* list of continents */
-  continentCList = gtk_clist_new_with_titles( 1, NULL);
-  gtk_clist_column_titles_hide( (GtkCList *)continentCList );
-  for(i=0;i<Ncontinents;i++) {
-    rowdata[0]=g_strdup(continents[i]);
-    row=gtk_clist_append( (GtkCList *) continentCList,rowdata);
-    g_free(rowdata[0]);
-  }
-  /*  gtk_container_add(GTK_CONTAINER(scrolled_window), continentCList);*/
-  gtk_widget_show (continentCList);
-  gtk_notebook_append_page (GTK_NOTEBOOK (*ZoneNotes), continentCList, label);
+		gtk_tree_store_set (store, &regionIter,
+				    REGION_NAME, name,
+				    CODE, code,
+				    -1);
+		regionItem = regionItem->next;
+	    }
+	    ClearNameCodeList(&regionList);
+
+	    countryItem = countryItem->next;
+	}
+	ClearNameCodeList(&countryList);
+    }
 
 
-  /* list of countries */
-  label = gtk_label_new (CountryLabel);
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  /* the vertical scroll policy should really be AUTOMATIC, but there is a 
-     problem that if you first view a list of countries not needing the 
-     scrollbar, then change to another list that does need it, the scrollbar 
-     does not appear.  That is the bar appears fixed according to its first
-     view, without updating.  Changing the policy to ALWAYS does not help,
-     the "apparent size" of the list seems fixed.
-     So, fix by upgrading to GtkTreeView.
-     This problem applies also to cities and regions below.
-  */ 
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-				  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-  gtk_widget_show (scrolled_window);
+    /* form the view of the tree */
 
-  countryCList = gtk_clist_new_with_titles( 1, NULL);
-  Zone->countryCList = countryCList;
-  gtk_clist_column_titles_hide( (GtkCList *)continentCList );
-  gtk_signal_connect(GTK_OBJECT( continentCList), "select_row",
-		     GTK_SIGNAL_FUNC(UpdateCountries),
-		     (gpointer)Zone);
-  gtk_widget_show (countryCList);
-  gtk_container_add(GTK_CONTAINER(scrolled_window), countryCList);
-  gtk_notebook_append_page (GTK_NOTEBOOK (*ZoneNotes), scrolled_window, label);
+    // continents
+    GtkTreeModel* filteredStore = gtk_tree_model_filter_new( GTK_TREE_MODEL(store), NULL );
+    
+    gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(filteredStore),
+					   FilterContinents,
+					   NULL, NULL );
 
 
-  /* list of cities and regions */
-  label = gtk_label_new (RegionLabel);
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  /* for some reason the horizontal scroll bars are turning themselves on
-     when policy is AUTOMATIC.  They shouldn't really be needed, so
-     turn them off.  (alternative is to manually set the window size).
-     Likewise for region list below, also */
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-				  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-  gtk_widget_show (scrolled_window);
+    *ZoneNotes = gtk_notebook_new ();
+    gtk_widget_show(*ZoneNotes);
+    g_object_set_data(G_OBJECT(*ZoneNotes), ZONE_DATA, Zone );
 
-  regionCList = gtk_clist_new_with_titles( 1, NULL);
-  Zone->regionCList = regionCList;
-  gtk_clist_column_titles_hide( (GtkCList *)regionCList );
-  gtk_signal_connect(GTK_OBJECT( countryCList), "select_row",
-		     GTK_SIGNAL_FUNC(UpdateRegions),
-		     (gpointer)Zone);
-  gtk_signal_connect(GTK_OBJECT(regionCList), "select_row",
-		     GTK_SIGNAL_FUNC(SelectRegion),
-		     (gpointer)Zone);
-  gtk_signal_connect(GTK_OBJECT(regionCList),
+    GtkWidget *label;
+    label = gtk_label_new (ContinentLabel);
+    GtkWidget *tree;
+
+    tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL(filteredStore));
+    gtk_tree_view_set_headers_visible( GTK_TREE_VIEW(tree), FALSE );
+    gtk_widget_show(tree);
+
+    GtkCellRenderer *renderer;
+    GtkTreeViewColumn *column;
+
+    renderer = gtk_cell_renderer_text_new ();
+    column = gtk_tree_view_column_new_with_attributes ("Name",
+						       renderer,
+						       "text", CONTINENT_NAME,
+						       NULL);
+    gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
+    gtk_notebook_insert_page(GTK_NOTEBOOK(*ZoneNotes), tree, 
+			     label, CONTINENT_NAME );
+
+    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW (tree));
+    gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+    g_signal_connect (G_OBJECT (selection), "changed",
+		      G_CALLBACK (UpdateCountries),
+		      (void*)*ZoneNotes);
+
+
+    // countries, in default continent
+    gboolean gotIt = findRow( GTK_TREE_MODEL(filteredStore),
+			      CONTINENT_NAME, defaultContinent, &continentIter );
+    path = NULL;
+    if ( gotIt )
+	gtk_tree_selection_select_iter( selection, &continentIter);
+
+    filteredStore = gtk_tree_view_get_model( Zone->countryTreeView );
+    selection = gtk_tree_view_get_selection( Zone->countryTreeView );
+    gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+    g_signal_connect (G_OBJECT (selection), "changed",
+		      G_CALLBACK (UpdateRegions),
+		      (void*)*ZoneNotes);
+
+
+
+    // regions, in default country
+    gotIt = findRow( GTK_TREE_MODEL(filteredStore), COUNTRY_NAME, defaultCountry, &countryIter );
+    if ( gotIt )
+	gtk_tree_selection_select_iter( selection, &countryIter);
+
+    filteredStore = gtk_tree_view_get_model( Zone->regionTreeView );
+    selection = gtk_tree_view_get_selection( Zone->regionTreeView );
+    gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+    g_signal_connect (G_OBJECT(selection), "changed",
+		      G_CALLBACK (SelectRegion),
+		      g_object_get_data(G_OBJECT(*ZoneNotes),ZONE_DATA));
+
+    g_signal_connect(G_OBJECT(Zone->regionTreeView),
 		     "button_press_event",
-		     GTK_SIGNAL_FUNC(ButtonPressedInRegionList),
+		     G_CALLBACK(ButtonPressedInRegionList),
 		     (gpointer)Zone);
-  gtk_widget_show (regionCList);
-  gtk_container_add(GTK_CONTAINER(scrolled_window), regionCList);
-  gtk_notebook_append_page (GTK_NOTEBOOK (*ZoneNotes), scrolled_window, label);
 
-  /* select Sydney, Australia (continent #6) as default */
-  /* note, gtk_clist_moveto doesn't seem to do anything ;/  */
-  gtk_clist_select_row( (GtkCList *)continentCList,6,0);
-  gtk_clist_select_row( (GtkCList *)countryCList,0,0);
-  gtk_clist_select_row( (GtkCList *)regionCList,3,0); 
-  /*  gtk_clist_moveto( (GtkCList *)continentCList, 6, 0, 0.5, 0.0 );*/
+    /* default region/city  */
+    gotIt = findRow( GTK_TREE_MODEL(filteredStore), REGION_NAME, defaultRegion, &regionIter );
+    if ( gotIt )
+    {
+	gtk_tree_selection_select_iter( selection, &regionIter);
+    }
+
+
 }
 
 
@@ -617,8 +854,6 @@ void AddZone( GtkWidget *w, gpointer clocklist )
   gtk_frame_set_shadow_type( (GtkFrame *)Frame, GTK_SHADOW_NONE); 
   gtk_box_pack_start (GTK_BOX (hbox), Frame, TRUE, FALSE, 5);
   gtk_widget_show (Frame);
-  /*  gtk_signal_connect (GTK_OBJECT (EntryDescription), "changed",
-      GTK_SIGNAL_FUNC (GetDescriptionString), (gpointer)&NewZone );*/
   gtk_container_add (GTK_CONTAINER (Frame), EntryDescription);
   /* where did the entry boxes get their default size from?
      Not setting the size here (and below for TZ) makes the dialog box too large 
@@ -632,8 +867,6 @@ void AddZone( GtkWidget *w, gpointer clocklist )
   gtk_frame_set_shadow_type( (GtkFrame *)Frame, GTK_SHADOW_NONE); 
   gtk_box_pack_start (GTK_BOX (hbox), Frame, TRUE, FALSE, 5);
   gtk_widget_show (Frame);
-  /*  gtk_signal_connect (GTK_OBJECT (EntryTZ), "changed",
-      GTK_SIGNAL_FUNC (GetTZstring), (gpointer)&NewZone );*/
   gtk_container_add (GTK_CONTAINER (Frame), EntryTZ);
   gtk_widget_set_usize( GTK_WIDGET(EntryTZ),125,0);
   gtk_widget_show (EntryTZ);
@@ -644,18 +877,18 @@ void AddZone( GtkWidget *w, gpointer clocklist )
   gtk_widget_show (hbox);
 
   AddButton = gtk_button_new_with_label (_("Add Zone"));
-  gtk_signal_connect (GTK_OBJECT (AddButton), "clicked",
-		      GTK_SIGNAL_FUNC (AddZoneToList), (gpointer)&NewZone );
+  g_signal_connect (G_OBJECT (AddButton), "clicked",
+		      G_CALLBACK (AddZoneToList), (gpointer)&NewZone );
   gtk_box_pack_start (GTK_BOX (hbox), AddButton, TRUE, FALSE, 0);
-  gtk_signal_connect (GTK_OBJECT (EntryDescription), "key-press-event",
-		      GTK_SIGNAL_FUNC (GotOK), (gpointer)AddButton);
-  gtk_signal_connect (GTK_OBJECT (EntryTZ), "key-press-event",
-		      GTK_SIGNAL_FUNC (GotOK), (gpointer)AddButton);
+  g_signal_connect (G_OBJECT (EntryDescription), "key-press-event",
+		      G_CALLBACK (GotOK), (gpointer)AddButton);
+  g_signal_connect (G_OBJECT (EntryTZ), "key-press-event",
+		      G_CALLBACK (GotOK), (gpointer)AddButton);
   gtk_widget_show (AddButton);
 
   DoneButton = gtk_button_new_with_label (_("Done"));
-  gtk_signal_connect (GTK_OBJECT (DoneButton), "clicked",
-		      GTK_SIGNAL_FUNC (DestroyWindow), (gpointer)window);
+  g_signal_connect (G_OBJECT (DoneButton), "clicked",
+		      G_CALLBACK (DestroyWindow), (gpointer)window);
   gtk_box_pack_start (GTK_BOX (hbox), DoneButton, TRUE, FALSE, 0);
   gtk_widget_show (DoneButton);
 
@@ -742,12 +975,12 @@ void ChangeZoneDescription(GtkWidget *w, gpointer clocklist)
   DescriptionEntry = gtk_entry_new();
   Zone.DescriptionEntry = DescriptionEntry;
   gtk_entry_set_text( (GtkEntry *) DescriptionEntry, description);
-  gtk_signal_connect (GTK_OBJECT (DescriptionEntry), "key-press-event",
-		      GTK_SIGNAL_FUNC (GotOKInDialog), (gpointer)window);
+  g_signal_connect (G_OBJECT (DescriptionEntry), "key-press-event",
+		      G_CALLBACK (GotOKInDialog), (gpointer)window);
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG(window)->vbox), DescriptionEntry);
   gtk_widget_show (DescriptionEntry);
 
-  g_signal_connect (GTK_OBJECT (window), "response",
+  g_signal_connect (G_OBJECT (window), "response",
 			    G_CALLBACK(WriteZoneDescription), 
 			    (gpointer)&Zone );
 
