@@ -8,6 +8,22 @@
 static const gchar *ZONE_TABLE="/usr/share/zoneinfo/zone.tab";
 static const gchar *COUNTRY_TABLE="/usr/share/zoneinfo/iso3166.tab";
 
+#define ZONE_DATA "ZoneData"
+
+/* entries in tree holding continent-region-city information */
+enum
+{
+   CONTINENT_NAME,
+   COUNTRY_NAME,
+   REGION_NAME,
+   CODE,
+   N_COLUMNS
+};
+
+static const gchar *defaultContinent = "Australia";
+static const gchar *defaultCountry = "Australia";
+static const gchar *defaultRegion = "Sydney";
+
 static const gchar *continents[] = 
 { "Africa",
   "Americas",
@@ -34,13 +50,11 @@ typedef struct NameCodeType {
 
 typedef struct AddZoneStruct 
 {
-  GObject *clocklist;
-  GtkWidget *countryCList;
-  GtkWidget *regionCList;
-  GtkWidget *DescriptionEntry;
-  GtkWidget *TZEntry;
-  GString *continent;
-  GString *country;
+    GObject *clocklist;
+    GtkTreeView *countryTreeView;
+    GtkTreeView *regionTreeView;
+    GtkWidget *DescriptionEntry;
+    GtkWidget *TZEntry;
 } AddZoneStruct;
 
 
@@ -77,24 +91,35 @@ GSList* FetchCountries(gchar *continent);
 /* input: country is the two-letter country code from ISO3166 */
 GSList* FetchRegions(gchar *country);
 
-void UpdateCountries(GtkWidget *ContinentCList,
+void UpdateCountries(GtkTreeSelection *selection, gpointer ZoneNotes);
+void UpdateRegions(GtkTreeSelection *selection, gpointer ZoneNotes);
+void SelectRegion(GtkTreeSelection *selection, gpointer ZoneNotes);
+
+
+void UpdateCountriesCL(GtkWidget *ContinentCList,
 		     gint row,
 		     gint column,
 		     GdkEventButton *event,
 		     gpointer ZoneData);
 
-/*  Why does the scroll box get larger when you keep selecting a country?? */
-void UpdateRegions(GtkWidget *CountryCList,
-		   gint row,
-		   gint column,
-		   GdkEventButton *event,
-		   gpointer ZoneData);
 
-void SelectRegion(GtkWidget *RegionCList,
-		  gint row,
-		  gint column,
-		  GdkEventButton *event,
-		  gpointer ZoneData);
+/* Implements GtkTreeModelFilterVisibleFunc, making continent entries
+   only visible.
+*/
+gboolean FilterContinents(GtkTreeModel *model,
+			  GtkTreeIter *iter,
+			  gpointer data);
+
+gboolean FilterCountries(GtkTreeModel *model,
+			 GtkTreeIter *iter,
+			 gpointer data);
+
+gboolean FilterRegions(GtkTreeModel *model,
+		       GtkTreeIter *iter,
+		       gpointer data);
+
+
+
 
 /* when left mouse button is double-clicked,
    send "key-pressed-event" to one of the Entry boxes 
@@ -110,7 +135,7 @@ gint ButtonPressedInRegionList(GtkWidget *regionlist,
    iso3166.tab)  Then the region (or city) of that country is identified, from 
    zone.tab.
 */
-void  PrepareZoneNotes(GtkWidget **ZoneNotes, AddZoneStruct *Zone);
+void PrepareZoneNotes(GtkWidget **ZoneNotes, AddZoneStruct *Zone);
 
 void AddZoneToList(GtkWidget *w, gpointer NewZone);
 
